<?php

	// This sets the attributes - including validation requirements and defaults
	$wpgayl_attributes = [
		"button_amount" => [
			"type" => "integer",
			"required_if_type" => ["button"]
		],
		"button_bg_colour" => [
			"type" => "hex",
			"default" => "#152f58",
			"required_if_type" => ["button", "form"]
		],
		"button_icon" => [
			"type" => "string",
			"default" => "chevron",
			"options" => ["arrow", "chevron", "logo", "heart"],
			"required_if_type" => ["button", "form"]
		],
		"button_image_url" => [
			"type" => "url",
			"url_prefix" => "https://admin.giveasyoulive.com/images/toolkit/donations/",
			"url_suffix" => ".png",
			"accepts_blank" => true, 
			"required_if_type" => ["button", "form"]
		],
		"button_radius" => [
			"type" => "integer",
			"default" => 30,
			"required_if_type" => ["button", "form"]
		],
		"button_repeat" => [
			"type" => "boolean",
			"default" => 0,
			"required_if_type" => ["button"]
		],
		"button_size" => [
			"type" => "string",
			"default" => "m",
			"options" => ["l", "m", "s"],
			"required_if_type" => ["button", "form"]
		],
		"button_text" => [
			"type" => "string",
			"default" => "Donate now",
			"required_if_type" => ["button", "form"]
		],
		"button_text_colour" => [
			"type" => "hex",
			"default" => "#ffffff",
			"required_if_type" => ["button", "form"]
		],
		"charity_id" => [
			"type" => "integer",
			"default" => 0,
			"minimum" => 2,
			"required_if_type" => ["button", "form", "page"]
		],
		"charity_name" => [
			"type" => "string",
			"accepts_blank" => true, // this is to avoid have 3x errors (id, name, uri) if charity is missing
		],
		"charity_uri" => [
			"type" => "string",
			"accepts_blank" => true, // this is to avoid have 3x errors (id, name, uri) if charity is missing
		],
		"form_amount_a" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_b" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_c" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_custom" => [
			"type" => "boolean",
			"default" => true,
			"required_if_type" => ["form"]
		],
		"form_amount_d" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_e" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_f" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_g" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_amount_h" => [
			"type" => "decimal",
			"minimum" => 5.00,
			"required_if_type" => ["form"]
		],
		"form_bg_colour" => [
			"type" => "hex",
			"default" => "#ffffff",
			"required_if_type" => ["form"]
		],
		"form_border_colour" => [
			"type" => "hex",
			"default" => "#454545",
			"required_if_type" => ["form"]
		],
		"form_border_width" => [
			"type" => "integer",
			"default" => 0,
			"required_if_type" => ["form"]
		],
		"form_description" => [
			"type" => "string",
			"accepts_blank" => true
		],
		"form_mode" => [
			"type" => "string",
			"default" => "both",
			"options" => ["both", "single", "repeat"],
			"required_if_type" => ["form"]
		],
		"form_show_gayl_message" => [
			"type" => "boolean",
			"default" => 1,
			"required_if_type" => ["form"]
		],
		"form_text_colour" => [
			"type" => "hex",
			"default" => "#454545",
			"required_if_type" => ["form"]
		],
		"form_title" => [
			"type" => "string",
			"required_if_type" => ["form"]
		],
		"page_type" => [
			"type" => "string",
			"options" => ["gaylo_charity", "gayld_charity", "gayld_donate"],
			"required_if_type" => ["page"]
		],
		"type" => [
			"type" => "string",
			"default" => "button",
			"options" => ["button", "form", "page"],
			"required" => true
		],
		"update_defaults" => [
			"type" => "boolean",
			"default" => false
		],
	];

	function wpgayl_validate($data) {
		global $wpgayl_attributes;

		if($data == null || empty($data)) {
			return ['valid' => false, 'errors' => []];
		}

		$wpgayl_validation_output = ['valid' => true];
		$wpgayl_errors = new WP_Error();

		foreach($wpgayl_attributes as $wpgayl_attribute_key => $wpgayl_attribute_value) {
			$wpgayl_attribute_key_pretty = preg_replace("/_[a-z]{1}$/", "", $wpgayl_attribute_key);
			$wpgayl_attribute_key_pretty = preg_replace("/_id$/", "", $wpgayl_attribute_key_pretty);
			$wpgayl_attribute_key_pretty = str_replace("_bg_", "_background_", $wpgayl_attribute_key_pretty);
			$wpgayl_attribute_key_pretty = ucfirst(str_replace("_", " ", $wpgayl_attribute_key_pretty));

			// Is field required at all times?
			if(isset($wpgayl_attribute_value["required"]) && $wpgayl_attribute_value["required"] === true) {
				if(!isset($data["wpgayl_" . $wpgayl_attribute_key])) {
					$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is required"));
					continue; // No point doing further validation
				}
			}
			
			// Is field required for the type? (button/form/page)
			if(isset($wpgayl_attribute_value["required_if_type"])) {
				if(isset($data['wpgayl_type']) && in_array($data['wpgayl_type'], $wpgayl_attribute_value["required_if_type"])) {
					if(!isset($data["wpgayl_" . $wpgayl_attribute_key])) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is required"));
						continue; // No point doing further validation
					}
				}
				else {
					unset($data["wpgayl_" . $wpgayl_attribute_key]);
					continue; // Field isn't needed by this type
				}
			}
			
			if(isset($wpgayl_attribute_value["type"])) {
				$wpgayl_new_value = null;
				$wpgayl_old_value = $data["wpgayl_" . $wpgayl_attribute_key];

				if($wpgayl_attribute_value["type"] === "string" || $wpgayl_attribute_value["type"] === "hex" || $wpgayl_attribute_value["type"] === "url") {
					$wpgayl_new_value = strval($wpgayl_old_value);

					// Check hex colour string is valid
					if($wpgayl_attribute_value["type"] === "hex") {
						if($wpgayl_new_value[0] != "#" || (strlen($wpgayl_new_value) != 4 && strlen($wpgayl_new_value) != 7)) {
							$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid colour"));
						}
					}
					
					// Check URL string is valid
					else if($wpgayl_attribute_value["type"] === "url") {
						$wpgayl_url_value = $wpgayl_new_value;

						if(isset($wpgayl_attribute_value["url_prefix"])) {
							$wpgayl_url_value = $wpgayl_attribute_value["url_prefix"] . $wpgayl_url_value;
						}
						if(isset($wpgayl_attribute_value["url_suffix"])) {
							$wpgayl_url_value = $wpgayl_url_value . $wpgayl_attribute_value["url_suffix"];
						}

						if(empty($wpgayl_new_value) && isset($wpgayl_attribute_value["accepts_blank"])) {
							// OK
						}
						elseif(!filter_var($wpgayl_url_value, FILTER_VALIDATE_URL)) {
							$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid URL"));
						}
					}

					// Check string is not null/empty
					else if(($wpgayl_old_value == null || empty($wpgayl_old_value)) && !isset($wpgayl_attribute_value["accepts_blank"])) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is required"));
					}

					// Check string matches one of the options
					else if(isset($wpgayl_attribute_value["options"]) && !in_array($wpgayl_new_value, $wpgayl_attribute_value["options"])   ) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid selection"));
					}
				}
				else if($wpgayl_attribute_value["type"] === "integer") {
					$wpgayl_new_value = intval($wpgayl_old_value);

					if(!is_int($wpgayl_new_value)) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid number"));
					}
				}
				else if($wpgayl_attribute_value["type"] === "decimal") {
					$wpgayl_new_value = floatval($wpgayl_old_value);

					if(!is_float($wpgayl_new_value)) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid amount"));
					}
					
					else if(isset($wpgayl_attribute_value["minimum"])) {
						if(isset($wpgayl_new_value) && !empty($wpgayl_new_value) && $wpgayl_new_value < $wpgayl_attribute_value["minimum"]) {
							$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " must be at least " . $wpgayl_attribute_value["minimum"]));
						}
					}
				}
				else if($wpgayl_attribute_value["type"] === "boolean") {
					$wpgayl_new_value = boolval($wpgayl_old_value);

					if(!is_bool($wpgayl_new_value)) {
						$wpgayl_errors->add('error', __($wpgayl_attribute_key_pretty . " is not a valid selection"));
					}
				}
			}

			// Updated the adjusted value
			if(isset($wpgayl_new_value)) {
				$data["wpgayl_" . $wpgayl_attribute_key] = $wpgayl_new_value;
			}
		}

		$wpgayl_validation_output["valid"] = !$wpgayl_errors->has_errors();
		$wpgayl_validation_output["errors"] = $wpgayl_errors;
		$wpgayl_validation_output["data"] = $data;

		return $wpgayl_validation_output;
	}