<?php 

	// Add CSS and JS
	wp_enqueue_style('giveasyoulive_admin');
	wp_enqueue_script('giveasyoulive_admin');

	// Do we have options?
	function wpgayl_has_defaults() {
		$options = get_option('wpgayl_settingsoptions');
		return isset($options) && !empty($options);
	}

	// Get default options from the database
	function wpgayl_get_defaults($input) {
		$options = get_option('wpgayl_settingsoptions');
		if(isset($options[$input])) return $options[$input];

		global $wpgayl_attributes; 

		if(isset($wpgayl_attributes[$input]) && isset($wpgayl_attributes[$input]["default"])) {
			return $wpgayl_attributes[$input]["default"] ?? null;
		}
	}

	// Compare 2 values
	function wpgayl_compare_values($value_1, $value_2, $is_default, $return_value) {
		if (isset($value_2) && $value_2 == $value_1) { 
			return $return_value;
		}
		else if ((!isset($value_2) || $value_2 == "") && $is_default) {
			return $return_value;
		}
	}

	// Used for checkboxes
	function wpgayl_is_checked($post_id, $input_name, $value, $is_default) {
		if(isset($post_id)) {
			$meta = unserialize(get_post_meta($post_id, 'wpgayl_data', true));
			$meta_value = $meta[$input_name] ?? null;
		}
		else {
			$meta_value = sanitize_text_field($_POST['wpgayl_' . $input_name] ?? null);
		}

		return wpgayl_compare_values($value, $meta_value, $is_default, 'checked');
	}

	// Used for radios
	function wpgayl_is_selected($post_id, $input_name, $value, $is_default) {
		if(isset($post_id)) {
			$meta = unserialize(get_post_meta($post_id, 'wpgayl_data', true));
			$meta_value = $meta[$input_name] ?? null;
		}
		else {
			$meta_value = sanitize_text_field($_POST['wpgayl_' . $input_name] ?? null);
		}

		return wpgayl_compare_values($value, $meta_value, $is_default, 'selected');
	}

	// Used for text/number inputs
	function wpgayl_get_value($post_id, $input_name) {
		if(isset($post_id)) {
			$meta = unserialize(get_post_meta($post_id, 'wpgayl_data', true));

			if(isset($meta) && isset($meta[$input_name]) && !empty($meta[$input_name])) {
				$output = $meta[$input_name];
			}
			else {
				$output = wpgayl_get_defaults(str_replace('wpgayl_', '', $input_name));
			}
		}
		else {
			if(isset($_POST['wpgayl_' . $input_name]) && !empty($_POST['wpgayl_' . $input_name])) { 
				$output = sanitize_text_field($_POST['wpgayl_' . $input_name]);
			}
			else {
				$output = wpgayl_get_defaults(str_replace('wpgayl_', '', $input_name));
			}
		}

		return stripslashes($output ?? '');
	}

	// Define $post_id in case it's missing - a random bug that I couldn't replicate
	$post_id = $post_id ?? null;
?>

<div class="wrap">
	<h1 class="wp-heading-inline"><?php echo (isset($_GET['action']) && $_GET['action'] == "edit") ? 'Update "' . esc_html($post_title)  .'"' : 'Create New' ?></h1>

	<a href="admin.php?page=wpgayl_buttons" class="page-title-action">Cancel</a>

	<form method="post" action="<?php echo esc_attr($_SERVER["REQUEST_URI"]); ?>">
		<?php

			if(isset($wpgayl_validation) && isset($wpgayl_validation['errors'])) {
				$wpgayl_errors = $wpgayl_validation['errors'];
				$wpgayl_error_messages = $wpgayl_errors->get_error_messages();

				foreach($wpgayl_error_messages as $wpgayl_error_message) {
					echo "<div class=\"notice notice-warning inline\"><p>" . esc_html($wpgayl_error_message) . "</p></div>";
				}
			}

			// Error message
			if (isset($error) && isset($error) && isset($message)) {
				echo "<div class='error'><p>"; echo esc_attr($message); echo"</p></div>";
			}
		?>

		<div id="poststuff">
			<div id="post-body" class="metabox-holder columns-2">

				<div id="postbox-container-1" class="postbox-container gayl-admin-examples">
					<h3 class="wp-heading-inline">Examples</h3>

					<figure>
						<figcaption>Custom button example</figcaption>
						<img src="https://ps.w.org/give-as-you-live/assets/screenshot-6.png?rev=2933990" alt="Custom button example" />
					</figure>
					
					<figure>
						<figcaption>Image button example</figcaption>
						<img src="https://admin.giveasyoulive.com/images/toolkit/donations/button-rect-donate-navy.png" alt="Image button example" />
					</figure>
					
					<figure>
						<figcaption>Form example</figcaption>
						<img src="https://ps.w.org/give-as-you-live/assets/screenshot-7.png?rev=2933990" alt="Form example" />
					</figure>
					
					<figure>
						<figcaption>Page example</figcaption>
						<img src="https://ps.w.org/give-as-you-live/assets/screenshot-8.png?rev=2933990" alt="Page example" />
					</figure>
				</div>

				<div id="postbox-container-2" class="postbox-container">
					<table class="form-table">
						<tbody>
							<!-- Charity ID -->
							<tr>
								<th scope="row"><label for="wpgayl_charity_id">Charity</label></th>
								<td>
									<div class="gayl-select2">
										<select type="number" name="wpgayl_charity_id" id="wpgayl_charity_id" class="js-gayl-select2" data-placeholder="Choose a charity">	
											<?php 
												if(wpgayl_get_value($post_id, 'charity_id') != null) {
											?>
												<option selected value="<?php echo esc_attr(wpgayl_get_value($post_id, 'charity_id')) ?>"><?php echo esc_attr(wpgayl_get_value($post_id, 'charity_name')) ?></option>
											<?php 
												}
											?>
										</select>

										<p class="description">Search using your charity name or registration number</p>

										<!-- Charity Name -->
										<input type="hidden" name="wpgayl_charity_name" id="wpgayl_charity_name" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'charity_name')) ?>" />

										<!-- Charity URI -->
										<input type="hidden" name="wpgayl_charity_uri" id="wpgayl_charity_uri" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'charity_uri')) ?>" />
									</div>
								</td>
							</tr>

							<!-- Type -->
							<tr>
								<th scope="row">Type</th>
								<td>
									<fieldset>
										<label for="wpgayl_type_button">
											<input type="radio" name="wpgayl_type" id="wpgayl_type_button" value="button" <?php echo esc_attr(wpgayl_is_checked($post_id, 'type', 'button', false)) ?> /> Button
										</label>
										<br />
										<label for="wpgayl_type_form">
											<input type="radio" name="wpgayl_type" id="wpgayl_type_form" value="form" <?php echo esc_attr(wpgayl_is_checked($post_id, 'type', 'form', false)) ?> /> Form
										</label>
										<br />
										<label for="wpgayl_type_page">
											<input type="radio" name="wpgayl_type" id="wpgayl_type_page" value="page" <?php echo esc_attr(wpgayl_is_checked($post_id, 'type', 'page', false)) ?> /> Page
										</label>
									</fieldset>
								</td>
							</tr>

							<!-- Form Mode -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_mode">Form Mode</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_form_mode_both">
											<input type="radio" name="wpgayl_form_mode" id="wpgayl_form_mode_both" value="both" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_mode', 'both', true)) ?> /> Both Single &amp; Repeat Donations
										</label>
										<br />
										<label for="wpgayl_form_mode_single">
											<input type="radio" name="wpgayl_form_mode" id="wpgayl_form_mode_single" value="single" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_mode', 'single', false)) ?> /> Single Donations Only
										</label>
										<br />
										<label for="wpgayl_form_mode_repeat">
											<input type="radio" name="wpgayl_form_mode" id="wpgayl_form_mode_repeat" value="repeat" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_mode', 'repeat', false)) ?> /> Repeat Donations Only
										</label>
									</fieldset>
								</td>
							</tr>

							<!-- Form Background -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_bg_colour">Form Background Colour</label></th>
								<td><input type="text" name="wpgayl_form_bg_colour" id="wpgayl_form_bg_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_bg_colour')) ?>"></td>
							</tr>

							<!-- Form Text Colour -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_text_colour">Form Text Colour</label></th>
								<td><input type="text" name="wpgayl_form_text_colour" id="wpgayl_form_text_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_text_colour')) ?>"></td>
							</tr>

							<!-- Form Border Colour -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_border_colour">Form Border Colour</label></th>
								<td><input type="text" name="wpgayl_form_border_colour" id="wpgayl_form_border_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_border_colour')) ?>"></td>
							</tr>

							<!-- Form Border Width -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_border_width">Form Border Width</label></th>
								<td>
									<div class="gayl-admin-input-group--right">
										<input type="number" inputmode="decimal" name="wpgayl_form_border_width" id="wpgayl_form_border_width" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_border_width')) ?>">
										<div><span>px</span></div>
									</div>
									<p class="description">Enter 0 or leave blank for no border</p>
								</td>
							</tr>

							<!-- Form Title -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_title">Form Title</label></th>
								<td><input type="text" name="wpgayl_form_title" id="wpgayl_form_title" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_title')) ?>"></td>
							</tr>

							<!-- Form Description -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_description">Form Description</label></th>
								<td><input type="text" name="wpgayl_form_description" id="wpgayl_form_description" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_description')) ?>"></td>
							</tr>
							
							<!-- Form Amounts -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_amount_a">Form Amounts</label></th>
								<td>
									<fieldset>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_a" id="wpgayl_form_amount_a" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_a')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_b" id="wpgayl_form_amount_b" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_b')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_c" id="wpgayl_form_amount_c" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_c')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_d" id="wpgayl_form_amount_d" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_d')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_e" id="wpgayl_form_amount_e" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_e')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_f" id="wpgayl_form_amount_f" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_f')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_g" id="wpgayl_form_amount_g" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_g')) ?>">
										</div>
										<div class="gayl-admin-input-group--left">
											<div><span>&pound;</span></div>
											<input type="number" inputmode="decimal" name="wpgayl_form_amount_h" id="wpgayl_form_amount_h" min="5" max="10000" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'form_amount_h')) ?>">
										</div>
									</fieldset>
									<p class="description">Minimum donation amount is &pound;5.</p>
								</td>
							</tr>

							<!-- Form Custom Amount -->
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_amount_custom">Enable Custom Amount</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_form_amount_custom_yes">
											<input type="radio" name="wpgayl_form_amount_custom" id="wpgayl_form_amount_custom_yes" value="1" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_amount_custom', '1', true)) ?> /> Yes
										</label>
										<br />
										<label for="wpgayl_form_amount_custom_no">
											<input type="radio" name="wpgayl_form_amount_custom" id="wpgayl_form_amount_custom_no" value="0" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_amount_custom', '0', false)) ?> /> No
										</label>
									</fieldset>
								</td>
							</tr>

							<!-- Form Button Type -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button" style="display: none;">
								<th scope="row"><label for="wpgayl_button_image_url">Button Type</label></th>
								<td>
									<?php $wpgayl_button_location = "https://admin.giveasyoulive.com/images/toolkit/donations" ?>
									<fieldset class="gayl-admin-button-images">
										<label for="wpgayl_button_image_url_custom" class="gayl-admin-button-custom">
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_custom" value="" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', '', true)) ?> />
											Custom Button
										</label>
										
										<p class="description">Or choose a button image from the below</p>
										<br />

										<label for="wpgayl_button_image_url_rect_donate_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-donate-navy.png" alt="Donate Button - Navy Rectangle" width="450" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_donate_navy" value="button-rect-donate-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-donate-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_rect_donate_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-donate-pink.png" alt="Donate Button - Pink Square" width="450" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_donate_pink" value="button-rect-donate-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-donate-pink', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_donate_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-donate-navy.png" alt="Donate Button - Navy Square" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_donate_navy" value="button-square-donate-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-donate-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_donate_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-donate-pink.png" alt="Donate Button - Pink Rectangle" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_donate_pink" value="button-square-donate-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-donate-pink', false)) ?> />
										</label>

										<br />

										<label for="wpgayl_button_image_url_rect_dd_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-dd-navy.png" alt="Repeat Donation Button - Navy Rectangle" width="450" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_dd_navy" value="button-rect-dd-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-dd-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_rect_dd_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-dd-pink.png" alt="Repeat Donation Button - Pink Rectangle" width="450" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_dd_pink" value="button-rect-dd-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-dd-pink', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_dd_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-dd-navy.png" alt="Repeat Donation Button - Navy Square" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_dd_navy" value="button-square-dd-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-dd-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_dd_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-dd-pink.png" alt="Repeat Donation Button - Pink Square" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_dd_pink" value="button-square-dd-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-dd-pink', false)) ?> />
										</label>

										<br />

										<label for="wpgayl_button_image_url_rect_fundraise_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-fundraise-navy.png" alt="Fundraise Button - Navy Rectangle" width="475" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_fundraise_navy" value="button-rect-fundraise-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-fundraise-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_rect_fundraise_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-rect-fundraise-pink.png" alt="Fundraise Button - Pink Rectangle" width="475" height="120" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_rect_fundraise_pink" value="button-rect-fundraise-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-rect-fundraise-pink', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_fundraise_navy">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-fundraise-navy.png" alt="Fundraise Button - Navy Square" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_fundraise_navy" value="button-square-fundraise-navy" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-fundraise-navy', false)) ?> />
										</label>
										<label for="wpgayl_button_image_url_square_fundraise_pink">
											<img src="<?php echo $wpgayl_button_location ?>/button-square-fundraise-pink.png" alt="Fundraise Button - Pink Square" width="170" height="150" class="" />
											<input type="radio" name="wpgayl_button_image_url" id="wpgayl_button_image_url_square_fundraise_pink" value="button-square-fundraise-pink" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_image_url', 'button-square-fundraise-pink', false)) ?> />
										</label>
									</fieldset>
								</td>
							</tr>
							
							<!-- Pre-Selected Amount -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button" style="display: none;">
								<th scope="row"><label for="wpgayl_button_amount">Pre-Selected Amount (Optional)</label></th>
								<td>
									<div class="gayl-admin-input-group--left">
										<div><span>&pound;</span></div>
										<input type="number" inputmode="decimal" name="wpgayl_button_amount" id="wpgayl_button_amount" min="0" step="0.01" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'button_amount')) ?>">
									</div>
									<p class="description">Donors will be able to choose a different amount if they wish. Leave blank or 0 to not set.</p>
								</td>
							</tr>
							
							<!-- Single or Repeat Donation -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button" style="display: none;">
								<th scope="row"><label for="wpgayl_button_repeat">Pre-Select Repeat Donation</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_button_repeat_y">
											<input type="radio" name="wpgayl_button_repeat" id="wpgayl_button_repeat_y" value="1" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_repeat', '1', false)) ?> /> Yes
										</label>
										<br />
										<label for="wpgayl_button_repeat_n">
											<input type="radio" name="wpgayl_button_repeat" id="wpgayl_button_repeat_n" value="0" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_repeat', '0', true)) ?> /> No
										</label>
									</fieldset>
								</td>
							</tr>
							
							<!-- Info -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button" style="display: none;">
								<th scope="row">&nbsp;</th>
								<td>
									<p class="description js-gayl-show-hide js-gayl-show-if-button-custom">The below settings affect both the button and the donation form it links to.</p>
									<p class="description js-gayl-show-hide js-gayl-show-if-button-image" style="display:none;">The below settings affect just donation form it links to - if you don't wish to change these, you can leave the defaults as they are.</p>
								</td>
							</tr>

							<!-- Button Background Colour -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_bg_colour">Button Background Colour</label></th>
								<td><input type="text" name="wpgayl_button_bg_colour" id="wpgayl_button_bg_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_value($post_id, 'button_bg_colour')) ?>"></td>
							</tr>
							
							<!-- Button Border Radius -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_radius">Button Roundness</label></th>
								<td>
									<div class="gayl-admin-input-group--right">
										<input type="number" inputmode="decimal" name="wpgayl_button_radius" id="wpgayl_button_radius" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'button_radius')) ?>">
										<div><span>px</span></div>
									</div>
								</td>
							</tr>

							<!-- Button Text Colour -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_text_colour">Button Text Colour</label></th>
								<td><input type="text" name="wpgayl_button_text_colour" id="wpgayl_button_text_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_value($post_id, 'button_text_colour')) ?>"></td>
							</tr>
							
							<!-- Button Size -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-button-custom js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_size">Button Size</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_button_size_s">
											<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_s" value="s" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_size', 's', false)) ?> /> Small
										</label>
										<br />
										<label for="wpgayl_button_size_m">
											<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_m" value="m" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_size', 'm', true)) ?> /> Medium
										</label>
										<br />
										<label for="wpgayl_button_size_l">
											<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_l" value="l" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_size', 'l', false)) ?> /> Large
										</label>
									</fieldset>
								</td>
							</tr>
							
							<!-- Button Text -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-button-custom js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_text">Button Text</label></th>
								<td><input type="text" name="wpgayl_button_text" id="wpgayl_button_text" value="<?php echo esc_attr(wpgayl_get_value($post_id, 'button_text')) ?>"></td>
							</tr>
							
							<!-- Button Icon -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-button-custom js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_button_icon">Button Icon</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_button_icon_chevron">
											<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_chevron" value="chevron" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_icon', 'chevron', true)) ?> /> Chevron (<?php echo wpgayl_create_chevron_icon() ?>)
										</label>
										<br />
										<label for="wpgayl_button_icon_arrow">
											<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_arrow" value="arrow" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_icon', 'arrow', false)) ?> /> Arrow (<?php echo wpgayl_create_arrow_icon() ?>)
										</label>
										<br />
										<label for="wpgayl_button_icon_heart">
											<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_heart" value="heart" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_icon', 'heart', false)) ?> /> Heart (<?php echo wpgayl_create_heart_icon() ?>)
										</label>
										<br />
										<label for="wpgayl_button_icon_logo">
											<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_logo" value="logo" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_icon', 'logo', false)) ?> /> Give as you Live Logo (<?php echo wpgayl_create_gayl_icon() ?>)
										</label>
										<br />
										<label for="wpgayl_button_icon_none">
											<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_none" value="none" <?php echo esc_attr(wpgayl_is_checked($post_id, 'button_icon', 'none', false)) ?> /> None
										</label>
									</fieldset>
								</td>
							</tr>
							
							<!-- GAYL Logo (on for everyone by default) -->
							<input type="hidden" name="wpgayl_form_show_gayl_message" id="wpgayl_form_show_gayl_message_yes" value="1" selected />

							<?php /*
							<tr class="js-gayl-show-hide js-gayl-show-if-form" style="display: none;">
								<th scope="row"><label for="wpgayl_form_show_gayl_message">Show 'Powered by Give as you Live Donate' Message</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_form_show_gayl_message_yes">
											<input type="radio" name="wpgayl_form_show_gayl_message" id="wpgayl_form_show_gayl_message_yes" value="1" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_show_gayl_message', '1', true)) ?> /> Yes
										</label>
										<br />
										<label for="wpgayl_form_show_gayl_message_no">
											<input type="radio" name="wpgayl_form_show_gayl_message" id="wpgayl_form_show_gayl_message_no" value="0" <?php echo esc_attr(wpgayl_is_checked($post_id, 'form_show_gayl_message', '0', false)) ?> /> No
										</label>
									</fieldset>
								</td>
							</tr>
							*/ ?>
							
							<!-- Page URL -->
							<tr class="js-gayl-show-hide js-gayl-show-if-page" style="display: none;">
								<th scope="row"><label for="wpgayl_page_type">Page</label></th>
								<td>
									<select name="wpgayl_page_type" id="wpgayl_page_type">
										<option value="" readonly>Select a page</option>
										<option value="gaylo_charity" <?php echo esc_attr(wpgayl_is_selected($post_id, 'page_type', 'gaylo_charity', false)) ?>>Give as you Live Online - Charity Page</option>
										<option value="gayld_charity" <?php echo esc_attr(wpgayl_is_selected($post_id, 'page_type', 'gayld_charity', false)) ?>>Give as you Live Donate - Charity Page</option>
										<option value="gayld_donate" <?php echo esc_attr(wpgayl_is_selected($post_id, 'page_type', 'gayld_donate', false)) ?>>Give as you Live Donate - Donation Page</option>
									</select>
								</td>
							</tr>
							
							<!-- Update Defaults -->
							<tr class="js-gayl-show-hide js-gayl-show-if-button js-gayl-show-if-form js-gayl-show-if-page" style="display: none;">
								<th scope="row"><label for="wpgayl_update_defaults">Update Defaults</label></th>
								<td>
									<fieldset>
										<label for="wpgayl_update_defaults_yes">
											<input type="radio" name="wpgayl_update_defaults" id="wpgayl_update_defaults_yes" value="1" <?php echo esc_attr(wpgayl_is_checked($post_id, 'update_defaults', '1', !wpgayl_has_defaults())) ?> /> Yes
										</label>
										<br />
										<label for="wpgayl_update_defaults_no">
											<input type="radio" name="wpgayl_update_defaults" id="wpgayl_update_defaults_no" value="0" <?php echo esc_attr(wpgayl_is_checked($post_id, 'update_defaults', '0', wpgayl_has_defaults())) ?> /> No
										</label>
									</fieldset>
									<p class="description">Updating the defaults will only affect new buttons, forms and pages that you create.</p>
								</td>
							</tr>
						</tbody>
					</table>
				</div>
			</div>
		</div>

		<input type="hidden" name="update" />

		<p class="submit" style="display:block; clear:left;">
			<input type="submit" class="button-primary" value="Save" onclick="this.form._wpnonce.value = '<?php echo esc_attr(wp_create_nonce('nonce_save')) ?>'; this.form.action.value = 'save'; return true;">
		</p>
	</form>
</div>