<?php
	//
	// Functions for dealing with the meta data on new/edit buttons pages
	//

	$wpgayl_post_meta = $wpgayl_post_meta ?? [];

	function wpgayl_is_valid($value) {
		return isset($value) && !empty($value);
	}

	// Allows us to loop through a bunch of fields and set the meta with just 1 line of code instead of many
	function wpgayl_set_metas($type, $names) {
		foreach($names as $name) {
			$wpgayl_post_meta = wpgayl_set_meta($type, $name, null);
		}

		return $wpgayl_post_meta;
	}

	// Set the meta - acts different if a int or string or boolean (later needs a $to_check field)
	function wpgayl_set_meta($type, $name, $to_check) {
		global $wpgayl_post_meta;

		if($type == "int" || $type == "integer") {
			$wpgayl_post_meta[$name] = intval($_POST['wpgayl_' . $name]);
		}
		elseif($type == "bool" || $type == "boolean") {
			$wpgayl_post_meta[$name] = intval($_POST['wpgayl_' . $name]) == $to_check;
		}
		else {
			$wpgayl_post_meta[$name] = sanitize_text_field(stripslashes($_POST['wpgayl_' . $name]));
		}

		return $wpgayl_post_meta;
	}

	function wpgayl_set_all_meta() {
		global $wpgayl_post_meta;

		// Set the core meta
		$wpgayl_post_meta = wpgayl_set_metas("text", ["id", "type", "charity_id", "charity_name", "charity_uri"]);

		// Set the button/form shared meta
		if($_POST['wpgayl_type'] == "button" || $_POST['wpgayl_type'] == "form") {
			$wpgayl_post_meta = wpgayl_set_metas("text", ["button_bg_colour", "button_text_colour", "button_size", "button_text", "button_icon"]);
			$wpgayl_post_meta = wpgayl_set_metas("int",  ["button_radius"]);
		}

		// Set the button meta
		if($_POST['wpgayl_type'] == "button") {
			$wpgayl_post_meta = wpgayl_set_metas("text", ["button_image_url"]);
			wpgayl_set_meta("bool", "button_repeat", 1);

			if(wpgayl_is_valid($_POST['wpgayl_button_amount']) && intval($_POST['wpgayl_button_amount']) != 0) {
				$wpgayl_post_meta = wpgayl_set_metas("int", ["button_amount"]);
			}
		}
		
		// Set the form meta
		if($_POST['wpgayl_type'] == "form") {
			$wpgayl_post_meta = wpgayl_set_metas("text", ["form_mode", "form_bg_colour", "form_text_colour", "form_border_colour", "form_border_width"]);
			wpgayl_set_meta("bool", "form_amount_custom", 1);
			wpgayl_set_meta("bool", "form_show_gayl_message", 1);
			
			// These are optional
			if(wpgayl_is_valid($_POST['wpgayl_form_title'])) {
				$wpgayl_post_meta = wpgayl_set_metas("text", ["form_title"]);
			}
			if(wpgayl_is_valid($_POST['wpgayl_form_description'])) {
				$wpgayl_post_meta = wpgayl_set_metas("text", ["form_description"]);
			}

			// We want the amounts to be in the right order
			$amounts = [];
			$letters = [0 => 'a', 1 => 'b', 2 => 'c', 3 => 'd', 4 => 'e', 5 => 'f', 6 => 'g', 7 => 'h'];
			foreach($letters as $i => $letter) {
				if(wpgayl_is_valid($_POST['wpgayl_form_amount_' . $letter]) && $_POST['wpgayl_form_amount_' . $letter] != "0") {
					array_push($amounts, floatval($_POST['wpgayl_form_amount_' . $letter]));
				}
			}

			sort($amounts);

			foreach($letters as $i => $letter) {
				if(isset($amounts[$i])) {
					$wpgayl_post_meta['form_amount_' . $letter] = $amounts[$i];
				}
			}
		}

		// Set the page meta
		if($_POST['wpgayl_type'] == "page") {
			$wpgayl_post_meta = wpgayl_set_metas("text", ["page_type"]);
		}

		return $wpgayl_post_meta;
	}

	function wpgayl_set_post_name() {
		global $wpgayl_post_meta;

		// Set the post name
		$wpgayl_post_name = "";
		if($wpgayl_post_meta['type'] == "button") {
			$details = [];
			if(!wpgayl_is_valid($wpgayl_post_meta['button_image_url'])) {
				$wpgayl_post_name .= "Custom Donate Button";
			}
			else {
				$wpgayl_post_name .= "Donate Button";
				array_push($details, trim(ucwords(str_replace("-", " ", str_replace("-dd-", "-Direct-Debit-", str_replace("button", "", $wpgayl_post_meta['button_image_url']))))));
			}

			if(wpgayl_is_valid($wpgayl_post_meta['button_repeat'])) {
				array_push($details, "Repeat Donation");
			}
			
			if(wpgayl_is_valid($wpgayl_post_meta['button_amount'])) {
				array_push($details, htmlentities("£") . $wpgayl_post_meta['button_amount'] . " Pre-Selected");
			}

			if(wpgayl_is_valid($details)) {
				$wpgayl_post_name .= " (" . implode(", ", $details) . ")";
			}
		}
		else if($wpgayl_post_meta['type'] == "form") {
			$wpgayl_post_name .= "Donate Form";

			if(wpgayl_is_valid($amounts)) {
				$amount_string = htmlentities("£") . implode(", " . htmlentities("£"), $amounts);
			}

			if(wpgayl_is_valid($wpgayl_post_meta['form_amount_custom'])) {
				$amount_string = (isset($amount_string) ? $amount_string . ", " : "") . "Custom";
			}

			$wpgayl_post_name .= " (" . $amount_string . ")";
		}
		else if($wpgayl_post_meta['type'] == "page") {
			if($wpgayl_post_meta['page_type'] == "gaylo_charity") {
				$wpgayl_post_name .= "Give as you Live Online - Charity Page";
			}
			else if($wpgayl_post_meta['page_type'] == "gayld_charity") {
				$wpgayl_post_name .= "Give as you Live Donate - Charity Page";
			}
			else if($wpgayl_post_meta['page_type'] == "gayld_donate") {
				$wpgayl_post_name .= "Give as you Live Donate - Donate Page";
			}
		}

		return $wpgayl_post_name;
	}
?>