<?php

	include_once ('attributes.php');

	// Get options from the database
	$wpgayl_raw_settings = get_option('wpgayl_settingsoptions');
	$wpgayl_settings = [];
	if(isset($wpgayl_raw_settings) && !empty($wpgayl_raw_settings)) {
		foreach ($wpgayl_raw_settings as $k => $v ) { 
			$wpgayl_settings[$k] = stripslashes($v);
		}
	}

	// Used for text/number inputs
	function wpgayl_get_setting($input_name) {
		global $wpgayl_settings;
		global $wpgayl_attributes; 

		if(isset($_POST['update'])){
			$output = sanitize_text_field($_POST['wpgayl_' . $input_name]) ?? null;
		}
		elseif(isset($wpgayl_settings) && array_key_exists($input_name, $wpgayl_settings)) {
			$output = $wpgayl_settings[$input_name] ?? null;
		}
		elseif(isset($wpgayl_attributes[$input_name]) && isset($wpgayl_attributes[$input_name]["default"])) {
			$output = $wpgayl_attributes[$input_name]["default"] ?? null;
		}

		return stripslashes($output ?? '');
	}

	function wpgayl_is_setting_checked($input_name, $value) {
		global $wpgayl_settings;
		global $wpgayl_attributes; 

		if (isset($wpgayl_settings[$input_name]) && $wpgayl_settings[$input_name] == $value) { 
			return "checked";
		}
		else if ((!isset($wpgayl_settings[$input_name]) || $wpgayl_settings[$input_name] == "") && isset($wpgayl_attributes[$input_name]["default"]) && $wpgayl_attributes[$input_name]["default"] == $value) {
			return "checked";
		}
	}

	// Allows us to loop through a bunch of fields and set the settings with just 1 line of code instead of many
	function wpgayl_set_settings($type, $names) {
		foreach($names as $name) {
			$wpgayl_settings = wpgayl_set_setting($type, $name, null);
		}

		return $wpgayl_settings;
	}

	// Set the setting - acts different if a int or string or boolean (later needs a $to_check field)
	function wpgayl_set_setting($type, $name, $to_check) {
		global $wpgayl_settings;
		global $wpgayl_attributes; 

		if($type == "int" || $type == "integer") {
			$wpgayl_settings[$name] = intval($_POST['wpgayl_' . $name]);
		}
		elseif($type == "bool" || $type == "boolean") {
			$wpgayl_settings[$name] = intval($_POST['wpgayl_' . $name]) == $to_check;
		}
		elseif(!empty(sanitize_text_field(stripslashes($_POST['wpgayl_' . $name])))) {
			$wpgayl_settings[$name] = sanitize_text_field(stripslashes($_POST['wpgayl_' . $name]));
		}
		elseif(isset($wpgayl_attributes[$name]) && isset($wpgayl_attributes[$name]["default"])) {
			$wpgayl_settings[$name] = $wpgayl_attributes[$name]["default"];
		}

		return $wpgayl_settings;
	}

	function wpgayl_plugin_options() {
		if ( !current_user_can( "manage_options" ) )  {
			wp_die( __( "You do not have sufficient permissions to access this page." ) );
		}

		// Add CSS and JS
		wp_enqueue_style('giveasyoulive_admin');
		wp_enqueue_script('giveasyoulive_admin');

	// End "}" is at bottom of the page"
	?>

<div class="wrap">
	<h1 class="wp-heading-inline">Give as you Live Settings</h1>
	<p>These are the default settings that apply whenever you create a new button or form. Changing these settings won't affect any existing buttons or forms.</p>

	<form method="post" action="<?php echo esc_attr($_SERVER["REQUEST_URI"]) ?>">
		<?php
			// Handle save/update
			if (isset($_POST['update'])) {

				if (!isset($_POST['action_save']) || ! wp_verify_nonce($_POST['action_save'],'nonce_save') ) {
					print 'Sorry, your nonce did not verify.';
					exit;
				}

				$wpgayl_settings = wpgayl_set_settings("int",  ["charity_id", "button_radius", "form_border_width"]);
				$wpgayl_settings = wpgayl_set_settings("text", ["charity_name", "charity_uri", "button_bg_colour", "button_bg_colour", "button_text_colour", "button_size", "button_text", "button_icon", "form_bg_colour", "form_text_colour", "form_border_colour", "form_border_width"]);

				update_option("wpgayl_settingsoptions", $wpgayl_settings);

				echo sprintf('<div id="message" class="notice notice-success"><p>%s</p></div>', esc_html("Settings Updated."));
			}
		?>

		<table class="form-table" role="presentation">
			<tbody>
				<!-- Charity ID -->
				<tr>
					<th scope="row"><label for="wpgayl_charity_id">Charity</label></th>
					<td>
						<div class="gayl-select2">
							<select type="number" name="wpgayl_charity_id" id="wpgayl_charity_id" class="js-gayl-select2" data-placeholder="Choose a charity">
								<?php 
									if(wpgayl_get_setting('charity_id') != null) {
								?>
									<option selected value="<?php echo esc_attr(wpgayl_get_setting('charity_id')) ?>"><?php echo esc_attr(wpgayl_get_setting('charity_name')) ?></option>
								<?php 
									}
								?>
							</select>

							<p class="description">Search using your charity name or registration number</p>

							<!-- Charity Name -->
							<input type="hidden" name="wpgayl_charity_name" id="wpgayl_charity_name" value="<?php echo esc_attr(wpgayl_get_setting('charity_name')) ?>" />

							<!-- Charity URI -->
							<input type="hidden" name="wpgayl_charity_uri" id="wpgayl_charity_uri" value="<?php echo esc_attr(wpgayl_get_setting('charity_uri')) ?>" />
						</div>
					</td>
				</tr>

				<!-- Button Background Colour -->
				<tr>
					<th scope="row"><label for="wpgayl_button_bg_colour">Button Background Colour</label></th>
					<td><input type="text" name="wpgayl_button_bg_colour" id="wpgayl_button_bg_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_setting('button_bg_colour')) ?>"></
				</tr>
				<tr>
					<th scope="row"><label for="wpgayl_button_radius">Button Roundness</label></th>
					<td>
						<div class="gayl-admin-input-group--right">
							<input type="number" inputmode="decimal" name="wpgayl_button_radius" id="wpgayl_button_radius" value="<?php echo esc_attr(wpgayl_get_setting('button_radius')) ?>">
							<div><span>px</span></div>
						</div>
					</td>
				</tr>

				<!-- Button Text Colour -->
				<tr>
					<th scope="row"><label for="wpgayl_button_text_colour">Button Text Colour</label></th>
					<td><input type="text" name="wpgayl_button_text_colour" id="wpgayl_button_text_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_setting('button_text_colour')) ?>"></
				</tr>

				<!-- Button Size -->
				<tr>
					<th scope="row">
						<label for="wpgayl_button_size">Button Size</label>
					</th>
					<td>
						<fieldset>
							<label for="wpgayl_button_size_s">
								<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_s" value="s" <?php echo esc_attr(wpgayl_is_setting_checked('button_size', 's')) ?> /> Small
							</label>
							<br />
							<label for="wpgayl_button_size_m">
								<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_m" value="m" <?php echo esc_attr(wpgayl_is_setting_checked('button_size', 'm')) ?> /> Medium
							</label>
							<br />
							<label for="wpgayl_button_size_l">
								<input type="radio" name="wpgayl_button_size" id="wpgayl_button_size_l" value="l" <?php echo esc_attr(wpgayl_is_setting_checked('button_size', 'l')) ?> /> Large
							</label>
						</fieldset>
					</td>
				</tr>

				<!-- Button Text-->
				<tr>
					<th scope="row"><label for="wpgayl_button_text">Button Text</label></th>
					<td><input type="text" id="wpgayl_button_text" name="wpgayl_button_text" value="<?php echo esc_attr(wpgayl_get_setting('button_text')) ?>" /></td>
				</tr>
				
				<!-- Button Icon -->
				<tr>
					<th scope="row"><label for="wpgayl_button_icon">Button Icon</label></th>
					<td>
						<fieldset>
							<label for="wpgayl_button_icon_chevron">
								<input type="radio" name="wpgayl_button_icon" id="button_icon_chevron" value="chevron" <?php echo esc_attr(wpgayl_is_setting_checked('button_icon', 'chevron')) ?> /> Chevron (<?php echo wpgayl_create_chevron_icon() ?>)
							</label>
							<br />
							<label for="wpgayl_button_icon_arrow">
								<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_arrow" value="arrow" <?php echo esc_attr(wpgayl_is_setting_checked('button_icon', 'arrow')) ?> /> Arrow (<?php echo wpgayl_create_arrow_icon() ?>)
							</label>
							<br />
							<label for="wpgayl_button_icon_heart">
								<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_heart" value="heart" <?php echo esc_attr(wpgayl_is_setting_checked('button_icon', 'heart')) ?> /> Heart (<?php echo wpgayl_create_heart_icon() ?>)
							</label>
							<br />
							<label for="wpgayl_button_icon_logo">
								<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_logo" value="logo" <?php echo esc_attr(wpgayl_is_setting_checked('button_icon', 'logo')) ?> /> Give as you Live Logo (<?php echo wpgayl_create_gayl_icon() ?>)
							</label>
							<br />
							<label for="wpgayl_button_icon_none">
								<input type="radio" name="wpgayl_button_icon" id="wpgayl_button_icon_none" value="none" <?php echo esc_attr(wpgayl_is_setting_checked('button_icon', 'none')) ?> /> None
							</label>
						</fieldset>
					</td>
				</tr>
				
				<!-- Form Background Colour -->
				<tr>
					<th scope="row"><label for="wpgayl_form_bg_colour">Form Background Colour</label></th>
					<td><input type="text" name="wpgayl_form_bg_colour" id="wpgayl_form_bg_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_setting('form_bg_colour')) ?>"></
				</tr>
				
				<!-- Form Text Colour -->
				<tr>
					<th scope="row"><label for="wpgayl_form_text_colour">Form Text Colour</label></th>
					<td><input type="text" name="wpgayl_form_text_colour" id="wpgayl_form_text_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_setting('form_text_colour')) ?>"></
				</tr>
				
				<!-- Form Border Colour -->
				<tr>
					<th scope="row"><label for="wpgayl_form_border_colour">Form Border Colour</label></th>
					<td><input type="text" name="wpgayl_form_border_colour" id="wpgayl_form_border_colour" class="js-gayl-spectrum" data-initial-colour="<?php echo esc_attr(wpgayl_get_setting('form_border_colour')) ?>"></
				</tr>
				
				<!-- Form Border Size -->
				<tr>
					<th scope="row"><label for="wpgayl_form_border_width">Form Border Size</label></th>
					<td>
						<div class="gayl-admin-input-group--right">
							<input type="number" inputmode="decimal" name="wpgayl_form_border_width" id="wpgayl_form_border_width" value="<?php echo esc_attr(wpgayl_get_setting('form_border_width')) ?>">
							<div><span>px</span></div>
						</div>
					</td>
				</tr>
			</tbody>
		</table>

		<input type='hidden' name='update' />
		<?php echo wp_nonce_field('nonce_save','action_save'); ?>

		<p class="submit">
			<input type="submit" name="submit" class="button button-primary" value="Save Settings" />
		</p>
	</form>
</div>

<?php
	// end settings page and required permissions
}