<?php

/**
 *
 * @link              https://www.giveasyoulive.com/
 * @since             1.0.13
 * @package           Give_As_You_Live
 *
 * @wordpress-plugin
 * Plugin Name:       Give as you Live
 * Plugin URI:        https://www.giveasyoulive.com/
 * Description:       Widgets and pre-build pages for UK charities using Give as you Live Online and Give as you Live Donate. 
 * Version:           1.0.13
 * Author:            Give as you Live
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       give-as-you-live
 * Domain Path:       /languages
 */

/*  Copyright 2021-2022 Matt Hallett, Give as you Live

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//// variables
$plugin_basename = plugin_basename(__FILE__);

define('WPGAYL_VERSION', '1.0.13');

//// plugin functions
wpgayl_wpgiveasyoulive::init_wpgiveasyoulive();

class wpgayl_wpgiveasyoulive {
	public static function init_wpgiveasyoulive() {
		register_deactivation_hook( __FILE__, array( __CLASS__, "wpgayl_deactivate" ));
		register_uninstall_hook( __FILE__, array( __CLASS__, "wpgayl_uninstall" ));
	}
	
	static function wpgayl_deactivate() {
		delete_option("wpgayl_notice_shown");
	}

	function wpgayl_uninstall() {
		//
	}
}

// Allow redirection, even if my theme starts to send output to the browser
add_action('init', 'wpgayl_do_output_buffer');
function wpgayl_do_output_buffer() {
	ob_start();
}

//// plugin includes

include_once('admin/buttons.php');
include_once('admin/functions.php');
include_once('admin/settings.php');
include_once('includes/functions.php');
include_once('includes/icons.php');
include_once('public/shortcode.php');

include_once('admin/api.php');
include_once('admin/block.php');

// CSS & JS
wp_register_script('giveasyoulive_admin', plugins_url('/admin/js/gayl.js', __FILE__), ['jquery'], WPGAYL_VERSION, true);
wp_register_script('giveasyoulive_public', plugins_url('/public/js/gayl.js', __FILE__), [], WPGAYL_VERSION, true);
wp_register_style('giveasyoulive_admin', plugins_url('/admin/css/gayl.css', __FILE__), [], WPGAYL_VERSION, 'screen');
wp_register_style('giveasyoulive_public', plugins_url('/public/css/gayl.css', __FILE__), [], WPGAYL_VERSION, 'screen');

function wp_gayl_charity_api_lookup(WP_REST_Request $request) {
	$parameters = $request->get_query_params();
	$term = trim($parameters['term'] ?? null);
	$id = trim($parameters['id'] ?? null);
	$empty = json_decode("{}");

	if(($term == null || empty($term)) && ($id == null || empty($id))) {
		return $empty;
	}

	try {
		$response = wp_remote_get('https://www.giveasyoulive.com/wordpress-cause-lookup?' . ($id != null ? 'id=' . $id : 'term=' . $term));

		if(wp_remote_retrieve_response_code($response) == 200) {
			return json_decode(wp_remote_retrieve_body($response));
		}	
	}
	catch (Exception $e) { 
		/* Do nothing as there's a return below */ 
	}

	return $empty;
}

// API 
add_action('rest_api_init', function () {
	register_rest_route('giveasyoulive/v1', '/charity', array(
		'methods' => 'GET',
		'callback' => 'wp_gayl_charity_api_lookup',
	));
});

?>